
* 更改文件目录
*投入产出表数据：io2017table149.dta
*税率和抵扣比例数据：taxrate2017n3_other.dta
 
*2025/05/30
*进行参数、税率、抵扣矩阵的计算
* 计算不同税制下经济增长率

* 利率参数是外生的
* ***  用2017年数据，增值税税率和营业税税率法定税率

 cap log close
 log using "财贸研究录用-正文附录表格",smcl replace

 use "io2017table149.dta", clear
/*a 使用mata 矩阵计算相关的变量，导入投入产出矩阵系数*/
mata:
mata clear
num=149
x=st_data((1,num),(4..(num+3))) /*中间投入*/
tot=st_data((1,num),"FI")      /*总产出*/
z=x'
length(tot)
rows(z)
cols(z)
A=luinv(diag(tot))*z
alpha=J(rows(A),1,1)-rowsum(A)

/*里昂惕夫逆矩阵*/
 L=luinv(I(rows(A))-A)

/* 消费权重*/
b=st_data((1,num),"FB") /*居民消费*/

theta=b/colsum(b)

end

  /*b导入149部门税率和抵扣关系矩阵*/
 
use "taxrate2017n3_other.dta", clear 



mata:
 /*导入增值税税率*/
  t12=st_data((1,149),"I") /*价外法定税率*/
  t17=st_data((1,149),"J")
  t19=st_data((1,149),"K")
  t30=st_data((1,149),"L")
 /*导入抵扣*/
  d0=st_data((1,149),"jxa") /*2012营改增之前*/
  d1=st_data((1,149),"jxb") /*2017年之后*/


 /*设定贴现率和价格变化利率 */
  
   beta=0.96     /*可调整，外生设定贴现率*/
   r=1/beta-1

end
   

 


/*********************************************/
/* 求解2012-2017-2019-2022 税制结果，需要求解名义利率
*****************************************/  
 
 
  /*参数和未知数,函数可以传递两个参数*/
  /*参数包括  消费者偏好 theta 公共品生产函数 epsi 利率r
    税率t12 留抵退税比例dr12,生产网络结构 alpha A,贴现率beta*/
  
 set more off
 mata:
 
      
	 //2012-2022 求解多玛系数和利率的函数
	 //A ,sig 函数输入: A 是生产网络矩阵  sig 是参数输入
	 // 函数输出依次为p 多玛系数,税收占总消费比例
	
	// growthfun()计算行业多马系数
   //mata drop growthfun()
  matrix function growthfun(A,theta,a,t,dr,dk,r)
    {  
	  
 	   real scalar    v
	   real vector lamba12,lamda
	   real matrix onem,mu0, mu12
	   
	   /*参数*/
	   /*theta    theta*/
	  /* a        alpha*/
	   /*t        VAT rate*/
	    
	  /* dr     留抵退税比例*/
	   /*dk     抵扣率*/
	    /*r        均衡利率*/     
	  
	   /*行业多马系数和中间矩阵构造*/
	 v=rows(A)
	 onem=J(v,v,1)
     mu0=(1+r)*(onem+(onem-diag(dr)*dk*dk')*diag(t))-diag(1:-dr)*dk*dk'*diag(t)
     mu12=(onem:/mu0) /*文章中E 矩阵*/
    
	 /*多玛矩阵*/
	   
     lamda=(theta:/(1:+t))'luinv(I(v)-(A:*mu12))  /*多马系数*/
	
	 /*税收矩阵和占比*/
       lamba12=I(v)-((dk*dk'):*(A:*mu12))
	   GamaT=lamda*lamba12*t
      /*劳动收入占比*/
	   GamaL=lamda*a
	   /*对数GDP和分解*/
	   lgdp1=-log(GamaL)
	   lgdp2=theta'*luinv(I(v)-A)*(A:*log(mu12))*J(v,1,1)
	   lgdp3=-theta'*log(1:+t)
	   LGDP=lgdp1+lgdp2+lgdp3
	   /*对数税收*/
	   LTAX=log(GamaT)-log(GamaL)
	   
	  /*税收负担分布和劳动力分布*/
	   taxb=lamba12*t
	   laind=(lamda':*a):/GamaL
	  
	  /*结果输出*/
	  pout=J(v,1,1)
	  pout[1,1]=LGDP
	  pout[2,1]=lgdp1
	  pout[3,1]=lgdp2
	  pout[4,1]=lgdp3
	  pout[5,1]=LTAX
	  
	  pout[6,1]=GamaL
	  pout[7,1]=GamaT
	  /*对数GDP，对数税收，劳动占比，税收占比，行业税负，工人分布，多马系数*/
	  return(pout,taxb,laind,lamda')
	}
 
/**************************/ 	


 /*****************************************/
 /*1-2012营改增之前结果*/
         /*计算税制参数*/
/*参数包括  消费者偏好 theta  税率t12 留抵退税比例dr12,*/
     dr12=J(rows(A),1,0)           /*留抵退税比例为0*/
	 dk12=d0
	 groth12=growthfun(A,theta,alpha,t12,dr12,dk12,r)
    
	  lngdp12=groth12[(1..5),1]
	  gama12=groth12[(6..7),1]
	  tauA12=groth12[.,2]          
	  labor12=groth12[.,3]
	  domar12=groth12[.,4]


 
 /*2-2017营改增全面完成，留抵结转下期抵扣*/
   /*参数包括  消费者偏好 theta 税率t17 加计扣除比例da17,留抵退税比例dr17,生产网络结构 alpha A,贴现率beta*/
 
 
     /*计算税制参数*/
	 dr17=J(rows(A),1,0)           /*留抵退税比例为0*/
	 dk17=d1

	 groth17=growthfun(A,theta,alpha,t17,dr17,dk17,r)
	  lngdp17=groth17[(1..5),1]
	  gama17=groth17[(6..7),1]
	  tauA17=groth17[.,2]          
	  labor17=groth17[.,3]
	  domar17=groth17[.,4]
	
 /*3-2019增值税减税降费，增量留抵0.6退税*/
     /*计算税制参数*/
	 dr19=J(rows(A),1,1)*0.6           /*留抵退税比例为0.6*/
	 dk19=d1
	 
	  groth19=growthfun(A,theta,alpha,t19,dr19,dk19,r)
	  lngdp19=groth19[(1..5),1]
	  gama19=groth19[(6..7),1]
	  tauA19=groth19[.,2]          
	  labor19=groth19[.,3]
	  domar19=groth19[.,4]
	 	 
	 
  /*4-2022增值税减税降费，增量留抵0.6退税,大规模减税降费部分行业留抵退税比例提高到1*/
     /*计算税制参数*/
	 dr22=st_data((1,149),"O")
	 dk22=d1
	 t22=t19
	 
	  
	  groth22=growthfun(A,theta,alpha,t22,dr22,dk22,r)
	  lngdp22=groth22[(1..5),1]
	  gama22=groth22[(6..7),1]
	  tauA22=groth22[.,2]          
	  labor22=groth22[.,3]
	  domar22=groth22[.,4]
	 	 
	
 /***************************************************************/
 /*2025-2030模拟所有行业留抵退税比例提高到1时，名义利率r不影响多玛系数和税收负担*/

 
  /*5-2025增值税减税降费，增量留抵100退税,大规模减税降费部分行业留抵退税比例提高到1*/
	/*全部行业抵扣都为1*/
	 dr25=J(rows(A),1,1)           /*留抵退税比例为1*/
	 dk25=d1
	 t25=t19
	
	groth25=growthfun(A,theta,alpha,t25,dr25,dk25,r)
	  lngdp25=groth25[(1..5),1]
	  gama25=groth25[(6..7),1]
	  tauA25=groth25[.,2]          
	  labor25=groth25[.,3]
	  domar25=groth25[.,4]
	
/*6-2030增值税减税降费，增量留抵100退税,税率下调到统一13%*/
     /*计算税制参数*/
 //t30从数据直接导入，免税部门税率为0
	            
	 dr30=J(rows(A),1,1)           /*留抵退税比例为0.6,1*/
	 dk30=d1
	
	  groth30=growthfun(A,theta,alpha,t30,dr30,dk30,r)
	  lngdp30=groth30[(1..5),1]
	  gama30=groth30[(6..7),1]
	  tauA30=groth30[.,2]          
	  labor30=groth30[.,3]
	  domar30=groth30[.,4]


  
  /*表结果总结*/
  
 lngdp=(lngdp12,lngdp17,lngdp19,lngdp22,lngdp25,lngdp30)

 t1lngdp=lngdp
 for(i=1;i<=5;i++) {
 t1lngdp[.,(i+1)]=lngdp[.,(i+1)]-lngdp[.,i]
 }
 	  

 table1=round(100*t1lngdp,0.001)'   /*以上一次改革为基准*/
 
 /*table 1 改革效果，以上一次改革为基准*/
 
 t1s1=("2016营改增" \ "2019税率简并" \ "2022留抵退税比例提高" \ "模拟留抵退税比例100%" \ "模拟全部行业13%" )
 
 /*正文表1输出*/
 /*税制改革	GDP变化	∆(-log⁡〖(Γ_L ))〗	∆(A∘Ξ ̃ )	∆(i+τ)	税收收入*/
  t1s1,strofreal(table1[(2..6),.])
  
 
      /* 经济增长和税收变化*/
 
 
 /*收入结构：税收占GDP比例,劳动收入占GDP比例*/
 
  gaTable0=(gama12,gama17,gama19,gama22,gama25,gama30)

   round( gaTable0,0.001)
 
 

   
    
/* 保存计算的税收负担和系数影响*/
  tauAa=(tauA12,tauA17,tauA19,tauA22,tauA25,tauA30) /*税收负担*/  
   st_matrix("taua",tauAa)
   stata("matrix colnames taua=tauA12 tauA17 tauA19 tauA22 tauA25 tauA30")
   stata("svmat taua,names(col)")
    mean(tauAa)
	colsum( (tauAa:<0))

	
	
end




* 数据分析和统计
*****************************
*表2    149个部门税收负担描述统计
**********************************
tabstat tauA12 tauA17 tauA19 tauA22 tauA25 tauA30 ,s( mean median sd min max N) col(stat)



* 计算改革税率变化部门
gen ch1=1*(tauA17<tauA12)+2*(tauA17==tauA12)+3*(tauA17>tauA12)
gen ch2=1*(tauA19<tauA17)+2*(tauA19==tauA17)+3*(tauA19>tauA17)
gen ch3=1*(tauA22<tauA19)+2*(tauA22==tauA19)+3*(tauA22>tauA19)
gen ch4=1*(tauA25<tauA22)+2*(tauA25==tauA22)+3*(tauA25>tauA22)
gen ch5=1*(tauA30<tauA25)+2*(tauA30==tauA25)+3*(tauA30>tauA25)
tab ch1
tab ch2
tab ch3
tab ch4
tab ch5

list E J if ch1>2 /*降税率改革服务部门负担加重了。*/

list E J if ch2>2 /*降税率改革服务部门负担加重了。*/


  

/* 列出负担为负数的行业*/
 foreach v of varlist  tauA12 tauA17 tauA19 tauA22 tauA25 tauA30 {
 count if `v'<0
 list E if `v'<0
 }
 
 
count if tauA17<0
count if tauA19<0
list E if tauA17<0
list E if tauA19<0



 /*************************************************************/

/*附表1 程序：计算2019年改革后各行业税率调整影响*/ 
/*************************************************************/

mata:
 matrix function magintax(A,theta,a,t,dr,dk,r)
 {
 
    v=rows(A)
	 onem=J(v,v,1)
     mu0=(1+r)*(onem+(onem-diag(dr)*dk*dk')*diag(t))-diag(1:-dr)*dk*dk'*diag(t)
     mu12=(onem:/mu0) /*文章中E 矩阵*/
    
	 /*多玛矩阵*/   
     lamda=(theta:/(1:+t))'luinv(I(v)-(A:*mu12))  /*多马系数*/  
      /*劳动收入占比*/
	   GamaL=lamda*a
	   
 /*价格对税率导数向量*/
 prdt19=(theta:/(1:+t))'+theta'*luinv(I(v)-A)*((A:*mu12):*((1+r)*(onem-dk*dk')+r*diag(1:-dr)*dk*dk'))
 
 /*theta对税率导数向量*/
 s19=luinv(I(v)-(A:*mu12))
 thetaD19=(1:/(1:+t)):*(s19*a)
 thetaS19=(theta:/(1:+t))'*s19*( I(v)-diag(1:+(r*dr))*((A:*mu12):*(mu12:*(dk*dk'))))
 thetdt19=(-thetaD19'):*thetaS19

 /*对数GDP对税率导数向量*/
 gdpdt19=-(1/GamaL)*thetdt19-prdt19
 lgdpdt19=gdpdt19'
 
 return( lgdpdt19)
 }
 
 mgdp12=magintax(A,theta,alpha,t12,dr12,dk12,r)
 mgdp17=magintax(A,theta,alpha,t17,dr17,dk17,r)
 mgdp19=magintax(A,theta,alpha,t19,dr19,dk19,r)
 mgdp22=magintax(A,theta,alpha,t22,dr22,dk22,r)
 mgdp25=magintax(A,theta,alpha,t25,dr25,dk25,r)
 mgdp30=magintax(A,theta,alpha,t30,dr30,dk30,r)
 
 Mgdp=(mgdp12,mgdp17,mgdp19,mgdp22,mgdp25,mgdp30)

  st_matrix("Mgdp",Mgdp)
   stata("matrix colnames Mgdp=mgdp12 mgdp17 mgdp19 mgdp22 mgdp25 mgdp30")
   stata("svmat Mgdp,names(col)")
    mean(Mgdp)
	colsum( (Mgdp:<0))
	
 end
 
 

*****************************
*附表1  边际税率调整经济效应
*****************************
gen tch=mgdp19*100

foreach v of varlist mgdp19 {
sort `v'
replace tch=`v'*100
replace tch=round(tch,0.001)
list E tch in 1/10
list E tch in -10/-1

/*统计边际效应正、负、无的企业数目*/
 count if tch>0
 count if tch<0
 count if tch==0
 
 }
 
 mata:
 stata("sort tch")
 b4=st_data((1,10),"tch")
 b3=st_sdata((1,10),"E")
 stata("gsort -tch")
 b2=st_data((1,10),"tch")
 b1=st_sdata((1,10),"E")
 
 /*附表1    边际税率调整的经济效应*/
 b1,strofreal(b2),b3,strofreal(b4)
 end
 
 

 sort G
  
 log close

 
